************************************************************
	*Title of dofile: WDR2020_chapter3_eventstudy.do 
	*Authors: Daria Taglioni (daglioni@worldbank.org)
	*This version: October 2019
	*This do file runs the event study regressions presented in chapter 3 and 5 of the World Development Report 2020.
	*See Figures 3.5, 3.9, and 3.13 of the Report
	*Please cite World Development Report 2020: Trading for Development in the Age of Global Value Chains. Washington, DC: World Bank.				
************************************************************
				
clear
set more off


use eventstudy.dta, clear


//----------------------------------------------------------------------------------
// 1. Calculate first year and last year countries are in one specific taxonomy group 
//----------------------------------------------------------------------------------

/* 
Groups are: commodity limited enhanced innovation
*/

	
local taxonomy_group
foreach y of varlist commodity limited enhanced innovation     {

qui bys iso3: egen firstyear_`y' = min(year) if `y'==1
qui gen startyear_`y' = firstyear_`y' if firstyear_`y'!=1990

qui bys iso3: egen lastyear_`y'= max(year) if `y'==1
qui gen stopyear_`y' = lastyear_`y' if lastyear_`y'!=2015

preserve
keep if `y'==1



summ `y'
tabstat startyear_`y' stopyear_`y', by(iso3) stat(mean) 

restore
}


local taxonomy_group  "commodity limited enhanced innovation"
local time "firstyear startyear lastyear stopyear"

preserve
collapse start* stop* first* last*, by(iso3) 

tabstat firstyear_commodity ///
		lastyear_commodity ///
		firstyear_limited ///
		lastyear_limited ///
		firstyear_enhanced ///
		lastyear_enhanced ///
		firstyear_innovation /// 
		lastyear_innovation /// 
		, by(iso3) stat(mean)
restore
 
save taxonomy-growth.dta, replace
 
//----------------------------------------------------------------------------------
// 2. Analysis

//----------------------------------------------------------------------------------


// 2.1 Prepare data for regressions 

local taxonomy_group
foreach y of varlist limited enhanced innovation  {
use taxonomy-growth.dta, clear

keep if `y'==1
rename firstyear_`y' firstyear
rename startyear_`y' startyear
rename lastyear_`y'  lastyear
rename stopyear_`y'  stopyear

//Exclude countries who are present in the taxonomy group of interest already in 1990 or there is no information about which group they belonged to before entering the group

drop if firstyear==1990
drop if startyear==.

//Restrict sample to min. 4 years of being part of a taxomy group, without gaps 
sort iso3 year 

gen cy_dif = year-year[_n-1] if iso3==iso3[_n-1]
bys iso3: egen cy_dif_max = max(cy_dif) 
gen nogaps = (cy_dif_max!=. & cy_dif_max<2 )
*browse iso3 year y firstyear startyear lastyear stopyear cy_dif cy_dif_max nogaps

gen cont_country = (stopyear-startyear>2 & stopyear-startyear!=. & nogaps==1)
replace cont_country = 1 if lastyear-startyear>2 & lastyear-startyear!=. & nogaps==1

//Create entry dummies
gen countryyear=year-startyear+1

//foreach x of numlist 1/25
forvalues x =1/25 {
gen entry`x' = (countryyear==`x')
}

// Create exit dummies 
gen countryyear2=stopyear-year+1

forvalues x =1/25 {
gen exit`x' = (countryyear2==`x')
}

// Limit the analysis to those observations that have at least three growth dummies per country
qui drop if startyear>2012 & startyear!=.
drop exit*
save `y'.dta, replace
}


//--------------------------------------------------------
// Regressions -- Growth after Entry into new taxonomy group
//--------------------------------------------------------


// distance from first year of entry in limited manufacturing


local taxonomy_group
foreach y of varlist limited enhanced innovation  {

use `y'.dta, clear 

drop entry1

xtreg lngdp_pc entry* i.year if year>1990 & cont_country==1 & lastyear>=2015, fe cluster(iso3)
outreg2 using "gdppc", excel dec(3)  append keep(entry*) addtext(`y')

xtreg lngini entry* i.year if year>1990 & cont_country==1 & lastyear>=2015, fe cluster(iso3)
outreg2 using "wages", excel dec(3)  append keep(entry*) addtext(`y') 

xtreg lnwage entry* i.year if year>1990 & cont_country==1 & lastyear>=2015, fe cluster(iso3)
outreg2 using "gini", excel dec(3)  append keep(entry*) addtext(`y')  
 
}



